@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2005 by Niklas Knutsson                                 *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -53,6 +53,21 @@ class QalculateEditMatrixVectorTableItem : public QTableItem {
 	
 };
 
+class QalculateEditMatrixTable : public QTable {
+
+	public:
+		
+		QalculateEditMatrixTable(QWidget *parent = 0, const char *name = 0) : QTable(parent, name) {}
+		QalculateEditMatrixTable(int numRows, int numCols, QWidget *parent = 0, const char *name = 0) : QTable(numRows, numCols, parent, name) {}
+
+		QWidget *beginEdit(int row, int col, bool replace) {
+			QWidget *w = QTable::beginEdit(row, col, replace);
+			((QLineEdit*) w)->selectAll();
+			return w;
+		}
+	
+};
+
 QalculateEditMatrixVectorDialog::QalculateEditMatrixVectorDialog(QWidget *parent, const char *name) : KDialogBase(parent, name, true, i18n("Edit Variable"), Ok | Cancel | Help, Ok, true) {
 
 	names_edit_dialog = NULL;
@@ -96,7 +111,7 @@ QalculateEditMatrixVectorDialog::QalculateEditMatrixVectorDialog(QWidget *parent
 	hbox->addWidget(vectorButton);
 	elementsLabel = new QLabel(i18n("Elements:"), mainWidget());
 	grid->addMultiCellWidget(elementsLabel, 7, 7, 0, 1);
-	elementsTable = new QTable(0, 0, mainWidget());
+	elementsTable = new QalculateEditMatrixTable(0, 0, mainWidget());
 	grid->addMultiCellWidget(elementsTable, 8, 8, 0, 1);
 
 	connect(namesButton, SIGNAL(clicked()), this, SLOT(editNames()));
@@ -463,7 +478,11 @@ void QalculateEditMatrixVectorDialog::nameChanged(const QString &name) {
 	}
 }
 
+#if QT_VERSION >= 0x030200
 QalculateEditMatrixVectorTableItem::QalculateEditMatrixVectorTableItem(QTable *table) : QTableItem(table, QTableItem::OnTyping) {}
+#else
+QalculateEditMatrixVectorTableItem::QalculateEditMatrixVectorTableItem(QTable *table) : QTableItem(table, QTableItem::OnTyping, QString::null) {}
+#endif
 QalculateEditMatrixVectorTableItem::QalculateEditMatrixVectorTableItem(QTable *table, const QString & text) : QTableItem(table, QTableItem::OnTyping, text) {}
 
 int QalculateEditMatrixVectorTableItem::alignment() const {return Qt::AlignRight;}
