@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Niklas Knutsson   *
- *   nq@altern.org   *
+ *   Copyright (C) 2005 by Niklas Knutsson                                 *
+ *   nq@altern.org                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -52,6 +52,21 @@ public:
 	
 };
 
+class QalculateInsertMatrixTable : public QTable {
+
+	public:
+		
+		QalculateInsertMatrixTable(QWidget *parent = 0, const char *name = 0) : QTable(parent, name) {}
+		QalculateInsertMatrixTable(int numRows, int numCols, QWidget *parent = 0, const char *name = 0) : QTable(numRows, numCols, parent, name) {}
+
+		QWidget *beginEdit(int row, int col, bool replace) {
+			QWidget *w = QTable::beginEdit(row, col, replace);
+			((QLineEdit*) w)->selectAll();
+			return w;
+		}
+	
+};
+
 
 QalculateInsertMatrixVectorDialog::QalculateInsertMatrixVectorDialog(QWidget *parent, const char *name) : KDialogBase(parent, name, true, i18n("Edit Variable"), Ok | Cancel | User1, Ok, true, KGuiItem(i18n("Insert Selection"))) {
 
@@ -75,7 +90,7 @@ QalculateInsertMatrixVectorDialog::QalculateInsertMatrixVectorDialog(QWidget *pa
 	hbox->addWidget(vectorButton);
 	elementsLabel = new QLabel(i18n("Elements:"), mainWidget());
 	grid->addMultiCellWidget(elementsLabel, 3, 3, 0, 1);
-	elementsTable = new QTable(0, 0, mainWidget());
+	elementsTable = new QalculateInsertMatrixTable(0, 0, mainWidget());
 	grid->addMultiCellWidget(elementsTable, 4, 4, 0, 1);
 	elementsTable->setSelectionMode(QTable::Single);
 	
@@ -155,7 +170,8 @@ void QalculateInsertMatrixVectorDialog::slotOk() {
 					QString str2 = elementsTable->text(index_r, index_c).stripWhiteSpace();
 					if(!str2.isEmpty()) {
 						if(b) {
-							matrixstr += ", ";
+							matrixstr += CALCULATOR->getComma();
+							matrixstr += " ";
 						} else {
 							b = true;
 						}
@@ -170,7 +186,8 @@ void QalculateInsertMatrixVectorDialog::slotOk() {
 		bool b1 = false;
 		for(int index_r = 0; index_r < r; index_r++) {
 			if(b1) {
-				matrixstr += ", ";
+				matrixstr += CALCULATOR->getComma();
+				matrixstr += " ";
 			} else {
 				b1 = true;
 			}
@@ -178,7 +195,8 @@ void QalculateInsertMatrixVectorDialog::slotOk() {
 			bool b2 = false;
 			for(int index_c = 0; index_c < c; index_c++) {
 				if(b2) {
-					matrixstr += ", ";
+					matrixstr += CALCULATOR->getComma();
+					matrixstr += " ";
 				} else {
 					b2 = true;
 				}
@@ -201,7 +219,8 @@ void QalculateInsertMatrixVectorDialog::insertSelection() {
 					QString str2 = elementsTable->text(index_r, index_c).stripWhiteSpace();
 					if(!str2.isEmpty()) {
 						if(b) {
-							matrixstr += ", ";
+							matrixstr += CALCULATOR->getComma();
+							matrixstr += " ";
 						} else {
 							b = true;
 						}
@@ -216,7 +235,8 @@ void QalculateInsertMatrixVectorDialog::insertSelection() {
 		bool b1 = false;
 		for(int index_r = sel.topRow(); index_r <= sel.bottomRow(); index_r++) {
 			if(b1) {
-				matrixstr += ", ";
+				matrixstr += CALCULATOR->getComma();
+				matrixstr += " ";
 			} else {
 				b1 = true;
 			}
@@ -224,7 +244,8 @@ void QalculateInsertMatrixVectorDialog::insertSelection() {
 			bool b2 = false;
 			for(int index_c = sel.leftCol(); index_c <= sel.rightCol(); index_c++) {
 				if(b2) {
-					matrixstr += ", ";
+					matrixstr += CALCULATOR->getComma();
+					matrixstr += " ";
 				} else {
 					b2 = true;
 				}
@@ -347,7 +368,11 @@ QString QalculateInsertMatrixVectorDialog::editMatrixVector(const MathStructure
 	return matrixstr;
 }
 
+#if QT_VERSION >= 0x030200
 QalculateInsertMatrixTableItem::QalculateInsertMatrixTableItem(QTable *table) : QTableItem(table, QTableItem::OnTyping) {}
+#else
+QalculateInsertMatrixTableItem::QalculateInsertMatrixTableItem(QTable *table) : QTableItem(table, QTableItem::OnTyping, QString::null) {}
+#endif
 QalculateInsertMatrixTableItem::QalculateInsertMatrixTableItem(QTable *table, const QString & text) : QTableItem(table, QTableItem::OnTyping, text) {}
 
 int QalculateInsertMatrixTableItem::alignment() const {return Qt::AlignRight;}
